| afttest.formula | R Documentation |
Model Diagnostics for AFT Models using Formulas
## S3 method for class 'formula'
afttest(
object,
data,
npath = 200,
testType = "omnibus",
estMethod = "rr",
eqType = "ns",
covTested = 1,
npathsave = 50,
linApprox = TRUE,
seed = NULL,
...
)
object |
A formula expression, of the form |
data |
An optional data frame in which to interpret the variables occurring in the formula. |
npath |
An integer value specifying the number of approximated processes. The default is given by 200. |
testType |
A character string specifying the type of the test. The following are permitted:
|
estMethod |
A character string specifying the type of the estimator used. The readers are referred to the aftgee package for details. The following are permitted:
|
eqType |
A character string specifying the type of the estimating equation used to obtain the regression parameters. The readers are referred to the aftgee package for details. The following are permitted:
|
covTested |
A character string specifying the covariate which will be tested.
The argument |
npathsave |
An integer value specifying the number of paths saved among all the paths. The default is given by 50. Note that it requires a lot of memory if saving all sampled paths (N by N matrix for each npath, and so npath*N*N elements). |
linApprox |
A logical value. If |
seed |
An optional integer specifying the random seed for reproducibility. |
... |
Other arguments passed to methods. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.